@@ -2,9 +2,9 @@
 from je_web_runner.selenium_wrapper.webdriver_manager import get_webdriver_manager
 from je_web_runner.selenium_wrapper.webdriver_with_options import set_webdriver_options_argument
 # test object
-from je_web_runner.test_object.test_object import TestObject
-from je_web_runner.test_object.test_object import create_test_object
-from je_web_runner.test_object.test_object import get_test_object_type_list
+from je_web_runner.utils.test_object.test_object_class import TestObject
+from je_web_runner.utils.test_object.test_object_class import create_test_object
+from je_web_runner.utils.test_object.test_object_class import get_test_object_type_list
 # selenium utils
 from je_web_runner.selenium_utils_wrapper.desired_capabilities.desired_capabilities import get_desired_capabilities
 from je_web_runner.selenium_utils_wrapper.desired_capabilities.desired_capabilities import get_desired_capabilities_keys
@@ -14,4 +14,3 @@ from je_web_runner.utils.executor.executor import execute_action
 from je_web_runner.selenium_wrapper.webdriver_wrapper import webdriver_wrapper
 # web element
 from je_web_runner.selenium_wrapper.web_element_wrapper import web_element_wrapper
-
